// ---------------------------------------------------------------------------
// energy_bar.cs -- Version 1.0 -- October 28, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Adds a small energy bar just above, below or beside your crosshairs
//
// Major thank you to LabRat for all his help!  The small energy bar would not
// exist if it wasn't for his code examples and generous assistance.
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\energy_bar.cs", "1.0", "Lorne Laliberte", "Oct 28, 2000");

include("writer\\energy.cs");
include("writer\\event.cs");
include("writer\\save.cs");
include("writer\\screensize.cs");
include("writer\\whud.cs");
include("writer\\you_died.cs");

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_energy_bar.cs file

    // Set energy bar start position
    //
    // 0 = top
    // 1 = right
    // 2 = bottom
    // 3 = left
    //
    $EnergyBar::Position = "3";

    // If you use xhair.cs, set how far away you want the energy bar
    // to be from the current crosshair, in pixels
    $EnergyBar::clearance = "5";

    // If you don't use xhair.cs, set how far away you want the energy bar
    // to be from the centre of the screen, in pixels
    $EnergyBar::radius = "36";

    // Toggle small energy bar on/off
    //bind(keyboard0, make, alt, "quote", TO, "EnergyBar::toggle();");

    // Cycle through energy bar positions
    //bind(keyboard0, make, "quote", TO, "EnergyBar::cycle();");

// ---------------------------------------------------------------------------

WriterPrefs::mount("energybarsupport", "writer\\energy_bar.vol");
WriterPrefs::load("energy_bar");

function EnergyBar::onYouSpawned()
{
    if(wHUD::exists(EnergyBar))
        wHUD::show(EnergyBar, "<b0,0:writer\\energybar\\" @ $EnergyBar::BitmapName @ "50.bmp>");
    else
        EnergyBar::make(true);

    return;
}

function EnergyBar::onYouRespawned()
{
    if(wHUD::exists(EnergyBar))
        wHUD::show(EnergyBar, "<b0,0:writer\\energybar\\" @ $EnergyBar::BitmapName @ "50.bmp>");
    else
        EnergyBar::make(true);

    return;
}

function EnergyBar::toggle()
{
    if(wHUD::isVisible(EnergyBar))
        wHUD::hide(EnergyBar);
    else
        wHUD::show(EnergyBar);
}

function EnergyBar::cycle()
{
    $EnergyBar::Position++;
    if($EnergyBar::Position > 3)
        $EnergyBar::Position = 0;

    EnergyBar::make();
}

function EnergyBar::make(%visible)
{
    if(%visible == "")
        %visible = wHUD::isVisible(EnergyBar);

    if($EnergyBar::Position == 0) // top
    {
        $EnergyBar::BitmapName = "bar";

        if($Xhair::currentBitmap != "")
            %y = floor(((getScreenSizeY() - 6 - $Xhair::currentHeight) / 2)) - $EnergyBar::clearance;
    	else
            %y = floor(((getScreenSizeY() - 6) / 2)) - $EnergyBar::radius;

        wHUD::make(EnergyBar, "50%", %y, 50, 5, 1, %visible, "<b0,0:writer\\energybar\\" @ $EnergyBar::BitmapName @ "50.bmp>");
	}
	else if($EnergyBar::Position == 1) // right
    {
        $EnergyBar::BitmapName = "sidebar";

        if($Xhair::currentBitmap != "")
            %x = floor(((getScreenSizeX() - 1 + $Xhair::currentWidth) / 2)) + $EnergyBar::clearance;
    	else
            %x = floor(((getScreenSizeX() - 1) / 2)) + $EnergyBar::radius;

        wHUD::make(EnergyBar, %x, "50%", 11, 50, 1, %visible, "<b0,0:writer\\energybar\\" @ $EnergyBar::BitmapName @ "50.bmp>");
	}
	else if($EnergyBar::Position == 2) // bottom
    {
        $EnergyBar::BitmapName = "bar";

        if($Xhair::currentBitmap != "")
            %y = floor(((getScreenSizeY() - 1 + $Xhair::currentHeight) / 2)) + $EnergyBar::clearance;
    	else
            %y = floor(((getScreenSizeY() - 1) / 2)) + $EnergyBar::radius;

        wHUD::make(EnergyBar, "50%", %y, 50, 5, 1, %visible, "<b0,0:writer\\energybar\\" @ $EnergyBar::BitmapName @ "50.bmp>");
	}
	else if($EnergyBar::Position == 3) // left
    {
        $EnergyBar::BitmapName = "sidebar";

        if($Xhair::currentBitmap != "")
            %x = floor(((getScreenSizeX() - 6 - $Xhair::currentWidth) / 2)) - $EnergyBar::clearance;
    	else
            %x = floor(((getScreenSizeX() - 6) / 2)) - $EnergyBar::radius;

        wHUD::make(EnergyBar, %x, "50%", 11, 50, 1, %visible, "<b0,0:writer\\energybar\\" @ $EnergyBar::BitmapName @ "50.bmp>", 0, 0, 0, 0);
	}
}

function EnergyBar::onEnergyChange(%energy)
{
    %i = floor((0.5 * %energy) + 0.5);
    wHUD::update(EnergyBar, "<b0,0:writer\\energybar\\" @ $EnergyBar::BitmapName @ %i @ ".bmp>");
    return;
}

function EnergyBar::Reset()
{
    wHUD::hide(EnergyBar);
}

function energy_bar::save()
{
    AddExportText("    // Set energy bar start position");
    AddExportText("    //");
    AddExportText("    // 0 = top");
    AddExportText("    // 1 = right");
    AddExportText("    // 2 = bottom");
    AddExportText("    // 3 = left");
    AddExportText("    //");
    ExportSetting("    $EnergyBar::Position", 3);
    AddExportText("");
    AddExportText("    // If you use xhair.cs, set how far away you want the energy bar");
    AddExportText("    // to be from the current crosshair, in pixels");
    ExportSetting("    $EnergyBar::clearance", 5);
    AddExportText("");
    AddExportText("    // If you don't use xhair.cs, set how far away you want the energy bar");
    AddExportText("    // to be from the centre of the screen, in pixels");
    ExportSetting("    $EnergyBar::radius", 36);
    AddExportText("");
    AddExportText("    // Toggle small energy bar on/off");

    ExportBind("EnergyBar::toggle();", "//bind(keyboard0, make, alt, \"quote\", TO, \"EnergyBar::toggle();\");");

    AddExportText("");
    AddExportText("    // Cycle through energy bar positions");

    ExportBind("EnergyBar::cycle();", "//bind(keyboard0, make, \"quote\", TO, \"EnergyBar::cycle();\");");
}

WriterPrefs::save("energy_bar");

function energy_bar::init()
{
    needs("writer\\energy_bar.cs", "writer\\energy.cs 1.1",
                                   "writer\\event.cs 2.7",
                                   "writer\\save.cs 2.3",
                                   "writer\\screensize.cs 1.1",
                                   "writer\\whud.cs 1.2",
                                   "writer\\you_died.cs 1.6",
                                   "writer\\you_respawned.cs 1.2",
                                   "writer\\you_spawned.cs 1.1");

    Event::Attach(eventEnergyChange, EnergyBar::onEnergyChange);
    Event::Attach(eventPilotModeOn, "wHUD::hide(EnergyBar);");
    Event::Attach(eventPilotModeOff, "wHUD::show(EnergyBar);");
    Event::Attach(eventYouSpawned, "EnergyBar::onYouSpawned();");
    Event::Attach(eventYouRespawned, "EnergyBar::onYouRespawned();");
    Event::Attach(eventYouDied, "wHUD::hide(EnergyBar);");
    Event::Attach(eventConnected, "EnergyBar::Reset();");
    Event::Attach(eventChangeMission, "EnergyBar::Reset();");
}
Event::Attach(writerInit, "energy_bar::init();");

if(!$UsingWriterLoader) energy_bar::init();
