// ---------------------------------------------------------------------------
// fire.cs -- Version 3.0 -- October 29, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Add events to the fire button (or key)
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\fire.cs", "3.0", "Lorne Laliberte", "Oct 29, 2000");

include("writer\\event.cs");
include("writer\\save.cs");

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_fire.cs file

    // Set this to your fire button!
    //bind(mouse0, make, "button0", to, "FirePressed();");
    //bind(mouse0, break, "button0", to, "FireReleased();");

// ---------------------------------------------------------------------------

WriterPrefs::load("fire");

function FirePressed()
{
    %weapon = getMountedItem(0);

    $Fire::pressed = true;

    Event::Trigger(eventFirePressed, %weapon); // %weapon will be -1 if no weapon mounted

    if( !Event::Returned(eventFirePressed, mute) )
    {
        postAction(2048, IDACTION_FIRE1, -0);

        if($Inv::reloadTime[%weapon] != "")
        {
            %now = getSimTime();
    
            if(%weapon == -1)
                return;
    
            %elapsed = %now - $Fire::lastFireTime;

            if(%elapsed < 0)
                %elapsed = 0;

            $Fire::time_between_shots = $Inv::fireTime[%weapon] + $Inv::reloadTime[%weapon];
            %wait = $Fire::time_between_shots - %elapsed;
    
            if(%wait < 0)
                %wait = 0;

            if($Inv::spinUp[%weapon])
            {
                $Fire::ammo_count = getItemCount($Inv::Ammo[%weapon]);
                Fire::spinner(%weapon);
                Event::Trigger(eventWeaponFired, %weapon);
                return;
            }
    
            if(%wait)
                schedule::add("Fire::shotFired(" @ %weapon @ ");", %wait, fireShotFired);
            else
                Fire::shotFired(%weapon);
        }
        Event::Trigger(eventWeaponFired, %weapon);
    }
}

// For spinning type weapons like the chaingun, it's easier just to watch for the ammo being used up :)
function Fire::spinner(%weapon)
{
    %ammo_count = getItemCount($Inv::Ammo[%weapon]);

    if(%ammo_count != $Fire::ammo_count)
        Event::Trigger(eventShotFired, %weapon);

    $Fire::ammo_count = %ammo_count;

    schedule::add("Fire::spinner(" @ %weapon @ ");", $Fire::time_between_shots / 4, fireSpinner);
}


function Fire::shotFired(%weapon)
{
    if($Fire::pressed)
    {
        %ammo = $Inv::Ammo[%weapon];

        if( (%ammo != "") && !getItemCount(%ammo))
        {
            Event::Trigger(eventNoAmmo, %weapon, %ammo);
            return;
        }

        $Fire::lastFireTime = getSimTime();

        if($Inv::fireTime[%weapon])
        {
            Event::Trigger(eventShotFired, %weapon);
            schedule::add("Fire::shotFired(" @ %weapon @ ");", $Fire::time_between_shots, fireShotFired);
        }
        else
        {
            // sustained-fire energy weapon
            $Fire::sustainedFire = true;
            Event::Trigger(eventSustainedFireBegun, %weapon);
        }
    }    
}

function Fire::report(%weapon)
{
    echo("Shot Fired by " @ $Inv::Name[%weapon] @ " (" @ %weapon @")");
    return;
}
//event::attach(eventShotFired, Fire::report);

function FireReleased()
{
    %weapon = getMountedItem(0);

    $Fire::pressed = false;

    Event::Trigger(eventFireReleased, %weapon); // %weapon will be -1 if no weapon mounted

    if( !Event::Returned(eventFireReleased, mute) )
    {
        postAction(2048, IDACTION_BREAK1, -0);

        if($Fire::sustainedFire)
        {
            $Fire::lastFireTime = getSimTime();
            $Fire::sustainedFire = false;
            Event::Trigger(eventSustainedFireEnded, %weapon);
        }

        $Fire::releaseTime = getSimTime();
        schedule::add("schedule::cancel(fireSpinner);", $Fire::time_between_shots);
        schedule::cancel(fireShotFired);

        Event::Trigger(eventWeaponBreak, %weapon);
    }
}

function Fire::reset()
{
    $Fire::sustainedFire = false;
    $Fire::releasedTime = getSimTime();

}

function fire::save()
{
    AddExportText("    // Set this to your fire button!");

    ExportBind("FirePressed();", "//bind(mouse0, make, button0, TO, \"FirePressed();\");");
    ExportBind("FireReleased();", "//bind(mouse0, break, button0, TO, \"FireReleased();\");");
}

WriterPrefs::save("fire");

function fire::init()
{
    needs("writer\\fire.cs", "writer\\event.cs 2.7",
                             "writer\\save.cs 2.3");

    Event::attach(eventConnected, "Fire::reset();");
    Event::attach(eventChangeMission, "Fire::reset();");
}
Event::Attach(writerInit, "fire::init();");

if(!$UsingWriterLoader) fire::init();
